<?php

namespace WPSynchro\Utilities\Licensing;

use WPSynchro\Transport\RemoteTransport;
use WPSynchro\Utilities\CommonFunctions;

/**
 * Class used for license handling (only used for PRO version)
 */
class Licensing
{
    const LICENSE_SERVER_SERVICE = 'https://wpsynchro.com/api/v1/license/';
    const MIGRATION_SERVER_SERVICE = 'https://wpsynchro.com/api/v1/synchronizerequest/';
    const LICENSE_STATE_OPTION_NAME = 'wpsynchro_license_key_validation';
    const PREDEFINED_LICENSE_KEY = 'B5E0B5F8DD8689E6ACA49DD6E6E1A930';  // Replace with your actual predefined key

    /**
     * Get license state
     * @return LicenseState
     */
    public function getLicenseState()
    {
        return (object) [
            'key' => self::PREDEFINED_LICENSE_KEY,
            'status' => true,
            'timestamp' => time(),
            'retries' => 0,
            'last_retry' => null
        ];
    }

    /**
     * Save license state
     * @param LicenseState $license_state
     */
    public function saveState($license_state)
    {
        // No operation needed as license is always valid
    }

    /**
     * Update license state
     * @param LicenseState $license_state
     */
    public function updateState($license_state)
    {
        // No operation needed as license is always valid
    }

    /**
     * Verify license
     */
    public function verifyLicense()
    {
        return true;  // Always return true as the license is considered always valid
    }

    /**
     * Check license key on license server
     */
    public function checkLicenseKeyOnLicenseServer($key, $remote_transport = null)
    {
        return true;  // Always return true as the license is considered always valid
    }

    /**
     * Get current license key
     */
    public function getCurrentLicenseKey()
    {
        return self::PREDEFINED_LICENSE_KEY;  // Always return the predefined license key
    }

    /**
     * Set current license key
     */
    public function setCurrentLicenseKey($license_key)
    {
        // No operation needed as license key is predefined and always valid
    }

    /**
     * Get license error message
     */
    public function getLicenseErrorMessage()
    {
        // This method may not be needed anymore since the license is always valid,
        // but you can keep it if you have other uses for it.
        return sprintf(__("%s uses a WP Synchro PRO version with a valid license key.", "wpsynchro"), get_home_url());
    }

    /**
     * Check if problems with licensing
     */
    public function hasProblemWithLicensing()
    {
        return false;  // Always return false as there are no problems with licensing
    }

    /**
     * Verify license when synchronizing
     */
    public function verifyLicenseForMigration($from_url, $to_url)
    {
        return true;  // Always return true for a valid license during migration
    }
}
